<? 
/* This file is part of JFFNMS
 * Copyright (C) <2002> Robert Bogdon 
 * Copyright (C) <2002-2005> Modifications by Javier Szyszlican <javier@szysz.com>
 * This program is licensed under the GNU GPL, full terms in the LICENSE file
 */

    function discovery_host_information ($ip,$rocommunity,$hostid,$param) { 

	if (strpos($param,",") > 1) 
	    $systems = explode(",",$param);
	else 
	    $systems[]=$param;

	if ($ip && $hostid && $rocommunity)
    	    $system_oid = snmp_walk($ip, $rocommunity, ".1.3.6.1.2.1.1.2"); // system.sysObjectID
	
	$system_oid = str_replace (".1.3.6.1.4.1","enterprises",$system_oid); //replace OID for enterprises

	$found = 0;
	foreach ($systems as $key=>$data) 
	    if (strpos($system_oid[0],trim($data)) > 1) $found = 1; 
    
        $cpu_info = array(); 

        if ($found==1) {
	    if ($ip && $hostid && $rocommunity)
    		$system_description = snmp_get($ip, $rocommunity, ".1.3.6.1.2.1.1.1.0"); // system.sysDescr

	    $cpu_info[1]["interface"] = "CPU";
	    $cpu_info[1]["admin"] = "ok"; 	//to show
	    $cpu_info[1]["oper"] = "up";  	//to be added by the AD
	    $cpu_info[1]["cpu_num"] = "1"; 	//FIXME detect more CPUs
	    
	    if (!empty($system_description)) 
		$cpu_info[1]["description"] = $system_description;
        }

        return $cpu_info; 
    } 
?>
